==> akonadi-calendar_15.12.3.orig.tar.xz: akonadi-calendar-15.12.3/src/freebusydownloadjob_p.h <==
/*
  Copyright (C) 2010 Bertjan Broeksema <broeksema@kde.org>
  Copyright (C) 2010 Klaralvdalens Datakonsult AB, a KDAB Group company <info@kdab.net>

  This library is free software; you can redistribute it and/or modify it
  under the terms of the GNU Library General Public License as published by
  the Free Software Foundation; either version 2 of the License, or (at your
  option) any later version.

  This library is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
  License for more details.

  You should have received a copy of the GNU Library General Public License
  along with this library; see the file COPYING.LIB.  If not, write to the
  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
  02110-1301, USA.
*/

#ifndef AKONADI_FREEBUSYDOWNLOADJOB_P_H
#define AKONADI_FREEBUSYDOWNLOADJOB_P_H

#include <KJob>
#include <QUrl>

namespace KIO
{
class Job;
}

namespace Akonadi
{

class FreeBusyDownloadJob : public KJob
{
    Q_OBJECT
public:
    explicit FreeBusyDownloadJob(const QUrl &url, QWidget *parentWidget = Q_NULLPTR);
    ~FreeBusyDownloadJob();

    void start() Q_DECL_OVERRIDE;

    QUrl url() const;
    QByteArray rawFreeBusyData() const;

private Q_SLOTS:
    void slotData(KIO::Job *, const QByteArray &data);
    void slotResult(KJob *job);

private:
    QUrl mUrl;
    QByteArray mFreeBusyData;
    QWidget *mParent;
};

}

#endif // FREEBUSYMANAGER_P_H

==> akonadi-calendar-17.03.80.tar.xz: akonadi-calendar-17.03.80/src/freebusydownloadjob_p.h <==
/*
  Copyright (C) 2010 Bertjan Broeksema <broeksema@kde.org>
  Copyright (C) 2010 Klaralvdalens Datakonsult AB, a KDAB Group company <info@kdab.net>

  This library is free software; you can redistribute it and/or modify it
  under the terms of the GNU Library General Public License as published by
  the Free Software Foundation; either version 2 of the License, or (at your
  option) any later version.

  This library is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
  License for more details.

  You should have received a copy of the GNU Library General Public License
  along with this library; see the file COPYING.LIB.  If not, write to the
  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
  02110-1301, USA.
*/

#ifndef AKONADI_FREEBUSYDOWNLOADJOB_P_H
#define AKONADI_FREEBUSYDOWNLOADJOB_P_H

#include <KJob>
#include <QUrl>

namespace KIO
{
class Job;
}

namespace Akonadi
{

class FreeBusyDownloadJob : public KJob
{
    Q_OBJECT
public:
    explicit FreeBusyDownloadJob(const QUrl &url, QWidget *parentWidget = nullptr);
    ~FreeBusyDownloadJob();

    void start() Q_DECL_OVERRIDE;

    QUrl url() const;
    QByteArray rawFreeBusyData() const;

private Q_SLOTS:
    void slotData(KIO::Job *, const QByteArray &data);
    void slotResult(KJob *job);

private:
    QUrl mUrl;
    QByteArray mFreeBusyData;
    QWidget *mParent;
};

}

#endif // FREEBUSYMANAGER_P_H
